#ifndef DBCHECK_H_
#define DBCHECK_H_

// Call after initialing the main db connection.
bool UpgradeTVDatabaseSchema(void);

#endif

